@@ -188,7 +188,123 @@ class BaseProvider:
         :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
         :return: list of features
         """
-        return list_alphas(freq)
+        return list_features(freq, ftype="alphas")
+
+    @staticmethod
+    def alpha_info(field, freq):
+        """
+        return the config of the field
+        :param field: features str
+        :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
+        :return:
+        """
+        return AlphaD.feature_info(field, freq)
+
+    @staticmethod
+    def factors(fields, start_time=None, end_time=None, freq="Tday", return_mat=False, instruments="all"):
+        """
+        :param instruments: instruments list or market (ei. "zz500", "hs300", "zz800", "zz1000", "all"
+        :param fields: features str or list
+        :param start_time:
+        :param end_time:
+        :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
+        :param return_mat: if return_mat, return nd-ns numpy array
+        :return:
+        """
+        if isinstance(fields, str):
+            fields = [fields, ]
+        if freq == "report_period":
+            fields += ["ann_date", ]
+        fields = list(fields)  # In case of tuple.
+        return FactorD.features(instruments, fields, start_time, end_time, freq, return_mat)
+
+    @staticmethod
+    def factors_mmat(fields, start_time=None, end_time=None, freq="Tday", instruments="all"):
+        """
+        :param instruments: instruments list or market (ei. "zz500", "hs300", "zz800", "zz1000", "all"
+        :param fields: features str or list
+        :param start_time:
+        :param end_time:
+        :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
+        :return: DataFrames that may have different shapes
+        """
+        if isinstance(fields, str):
+            fields = [fields, ]
+        if freq == "report_period":
+            fields += ["ann_date", ]
+        fields = list(fields)  # In case of tuple.
+        return FactorD.features_mmat(instruments, fields, start_time, end_time, freq)
+
+    @staticmethod
+    def list_factors(freq="*"):
+        """
+        :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
+        :return: list of features
+        """
+        return list_features(freq, ftype="factors")
+
+    @staticmethod
+    def factor_info(field, freq):
+        """
+        return the config of the field
+        :param field: features str
+        :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
+        :return:
+        """
+        return FactorD.feature_info(field, freq)
+
+    @staticmethod
+    def combs(fields, start_time=None, end_time=None, freq="Tday", return_mat=False, instruments="all"):
+        """
+        :param instruments: instruments list or market (ei. "zz500", "hs300", "zz800", "zz1000", "all"
+        :param fields: features str or list
+        :param start_time:
+        :param end_time:
+        :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
+        :param return_mat: if return_mat, return nd-ns numpy array
+        :return:
+        """
+        if isinstance(fields, str):
+            fields = [fields, ]
+        if freq == "report_period":
+            fields += ["ann_date", ]
+        fields = list(fields)  # In case of tuple.
+        return FactorD.features(instruments, fields, start_time, end_time, freq, return_mat)
+
+    @staticmethod
+    def combs_mmat(fields, start_time=None, end_time=None, freq="Tday", instruments="all"):
+        """
+        :param instruments: instruments list or market (ei. "zz500", "hs300", "zz800", "zz1000", "all"
+        :param fields: features str or list
+        :param start_time:
+        :param end_time:
+        :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
+        :return: DataFrames that may have different shapes
+        """
+        if isinstance(fields, str):
+            fields = [fields, ]
+        if freq == "report_period":
+            fields += ["ann_date", ]
+        fields = list(fields)  # In case of tuple.
+        return FactorD.features_mmat(instruments, fields, start_time, end_time, freq)
+
+    @staticmethod
+    def list_combs(freq="*"):
+        """
+        :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
+        :return: list of features
+        """
+        return list_features(freq, ftype="combs")
+
+    @staticmethod
+    def comb_info(field, freq):
+        """
+        return the config of the field
+        :param field: features str
+        :param freq: includdes Aday for natural day; Tday for trading day; report_period for financial statement
+        :return:
+        """
+        return CombD.feature_info(field, freq)
 
     @staticmethod
     def list_datasets():
@@ -505,9 +621,12 @@ class BaseDataProvider:
 class FeatureProvider(BaseDataProvider):
     """Dataset provider class: Provide Dataset data."""
 
+    def __init__(self, ftype="features"):
+        self.ftype = ftype
+
     @property
     def _uri_data(self):
-        return os.path.join(data_path, "features", "{}", "{}.h5")
+        return os.path.join(data_path, self.ftype, "{}", "{}.h5")
 
     @property
     def _uri_cfg(self):
@@ -642,18 +761,6 @@ class FeatureProvider(BaseDataProvider):
         return json_cfg
 
 
-class AlphaProvider(FeatureProvider):
-
-    @property
-    def _uri_data(self):
-        return os.path.join(data_path, "alphas", "{}", "{}.h5")
-
-    @property
-    def _uri_cfg(self):
-        """Static feature file uri."""
-        return os.path.join(data_path, "alphas", "{}", "{}_config.json")
-
-
 class DatasetProvider(BaseDataProvider):
     """Dataset provider class: Provide Dataset data."""
 
@@ -773,15 +880,14 @@ class DatasetProvider(BaseDataProvider):
         return code_flt, time_flt, others, is_annrepo, format_, label_match
 
 
-def list_features(freq="*"):
-    features = (Path(data_path) / "features").glob(f"**/{freq}/*.h5")
-    features = [i.name.replace(".h5", "") for i in features]
-    return features
-
-
-def list_alphas(freq="*"):
-    features = (Path(data_path) / "alphas").glob(f"**/{freq}/*.h5")
+def list_features(freq="*", ftype="features"):
+    features = (Path(data_path) / ftype).glob(f"**/{freq}/*.h5")
     features = [i.name.replace(".h5", "") for i in features]
+    for i in list(cal_config.keys()):
+        try:
+            features.remove(i)
+        except:
+            pass
     return features
 
 
@@ -859,8 +965,10 @@ def parse_field(field):
 
 
 DatasetD = DatasetProvider()
-FeatureD = FeatureProvider()
-AlphaD = AlphaProvider()
+FeatureD = FeatureProvider("features")
+AlphaD = FeatureProvider("alphas")
+FactorD = FeatureProvider("factors")
+CombD = FeatureProvider("combss")
 Cal = CalendarProvider()
 Inst = InstrumentProvider()
 D = BaseProvider()
