@@ -35,7 +35,7 @@ class FeatureUpdater:
         self.freq = freq
         self.start_time = start_time
         self.end_time = end_time
-        self.save_primarykey = is_alpha
+        self.not_save_primarykey = is_alpha
 
     @property
     def _uri_data(self):
@@ -70,7 +70,7 @@ class FeatureUpdater:
         if config is None:
             config = {}
         value_dict = Mdf.to_dict("series")
-        if self.save_primarykey:
+        if self.not_save_primarykey:
             value_dict.pop(self.cal_config[self.freq]["col_name"])
         for field, values in value_dict.items():
             config_i = config.get(field, None)
@@ -92,24 +92,43 @@ class FeatureUpdater:
 
 class AlphaUpdater(FeatureUpdater):
     """ save more complex alphas based on any time index of the api in, load from local with D.alphas"""
-    def __init__(self, stk_univ="all", start_time=None, end_time=None, freq="Tday", save_primarykey=False):
-        super(AlphaUpdater, self).__init__(stk_univ, start_time, end_time, freq, save_primarykey)
+    def __init__(self, stk_univ="all", start_time=None, end_time=None, freq="Tday", save_primarykey=False, ftype="alphas"):
+        super(AlphaUpdater, self).__init__(stk_univ, start_time, end_time, freq, not save_primarykey)
+        self.ftype = ftype
 
     @property
     def _uri_data(self):
         """Static feature file uri."""
-        return os.path.join(data_path, "alphas", "{}", "{}.h5")
+        return os.path.join(data_path, self.ftype, "{}", "{}.h5")
 
     @property
     def _uri_cfg(self):
         """Static feature file uri."""
-        return os.path.join(data_path, "alphas", "{}", "{}_config.json")
+        return os.path.join(data_path, self.ftype, "{}", "{}_config.json")
 
     def save_alpha(self, alpha, alpha_name, config=None):
         alpha = alpha.rename(columns={"value": alpha_name})
         self.save_values(alpha, self.cal_config[self.freq]["col_name"], "stockcode", config)
 
 
+class FactorUpdater(AlphaUpdater):
+    """ save more derived factors based on any time index of the api in, load from local with D.factors"""
+    def __init__(self, stk_univ="all", start_time=None, end_time=None, freq="Tday", save_primarykey=False):
+        super(FactorUpdater, self).__init__(stk_univ, start_time, end_time, freq, save_primarykey, ftype='factors')
+
+    def save_factor(self, factor, factor_name, config=None):
+        self.save_alpha(factor, factor_name, config)
+
+
+class CombUpdater(AlphaUpdater):
+    """ save more derived combs based on any time index of the api in, load from local with D.combs"""
+    def __init__(self, stk_univ="all", start_time=None, end_time=None, freq="Tday", save_primarykey=False):
+        super(CombUpdater, self).__init__(stk_univ, start_time, end_time, freq, save_primarykey, ftype='combs')
+
+    def save_comb(self, comb, comb_name, config=None):
+        self.save_alpha(comb, comb_name, config)
+
+
 class FeatureSaver(FeatureUpdater):
     """ save basic alphas based on complete time index of the api in, load from local with D.features"""
     def __init__(self, freq):
